---

slug: /spatial-data-type-overview

---

# Spatial reference systems (SRS)

A spatial reference system (SRS) is a coordinate-based system for geographic locations. seekdb currently supports only the SRS that is supported by default.

Spatial reference systems generally include the following types:

* Projected SRS. A projected SRS is a projection of the Earth onto a plane, which is a flat map. The coordinate system on this plane is a Cartesian coordinate system, using units of length (such as meters and feet) instead of latitude and longitude.

* Geographic SRS. A geographic SRS is a non-projected SRS that represents latitude and longitude (or latitude-longitude) coordinates on an ellipsoid using any angular unit.

In addition, there is a flat Cartesian plane represented by `SRID 0`, which has no assigned units for its axes. Unlike projected SRS, it is an abstract plane without geographic reference and does not necessarily represent the Earth. `SRID 0` is the default `SRID` for spatial data.

You can obtain SRS information from the `INFORMATION_SCHEMA ST_SPATIAL_REFERENCE_SYSTEMS` table, as shown in the following example:

```sql
SELECT *  FROM INFORMATION_SCHEMA.ST_SPATIAL_REFERENCE_SYSTEMS
     WHERE SRS_ID = 4326\G
```

The result is as follows:

```sql
*************************** 1. row ***************************
                SRS_NAME: WGS 84
                  SRS_ID: 4326
            ORGANIZATION: EPSG
ORGANIZATION_COORDSYS_ID: 4326
              DEFINITION: GEOGCS["WGS 84",DATUM["World Geodetic System 1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.017453292519943278,AUTHORITY["EPSG","9122"]],AXIS["Lat",NORTH],AXIS["Lon",EAST],AUTHORITY["EPSG","4326"]]
             DESCRIPTION: NULL
1 row in set (0.002 sec)
```

In the preceding example, the SRS used for the GPS system is described. Its name (SRS_NAME) is WGS 84, and its ID (SRS_ID) is 4326.

The SRS definitions in the `DEFINITION` column are `WKT` values. WKT is defined based on EBNF (Extended Backus Naur Form). WKT can be used as a data format (referred to as WKT-Data in this text) or for defining SRS in GIS.

The `SRS_ID` value represents a value of the same type as the `SRID` of a geometry value or a value passed as the `SRID` parameter to a spatial function. `SRID 0` (a unitless Cartesian plane) is a special and valid spatial reference system ID that can be used for any spatial data calculations that depend on the `SRID` value.

For calculations involving multiple geometry values, all values must have the same SRID; otherwise, an error will occur.